package JiftyWiki::Model::Page::Schema;
use Jifty::DBI::Schema;

column name => 
    type is 'text',
    is mandatory,
    is distinct;

column content =>
    type is 'text',
    render_as 'textarea';

column updated =>,
    type is 'timestamp',
    since '0.0.6';

#column revisions => refers_to JiftyWiki::Model::Revision by 'page';

package JiftyWiki::Model::Page;
use base qw/Jifty::Record/;
use Text::WikiFormat;


sub wiki_content {
    my $self = shift;
    my $content = $self->content();

    my $wikitext = Text::WikiFormat::format($content, {prefix => '/view/'});
    return($wikitext);
}


sub create {
    my $self = shift;
    my %args = (@_);
    my $now = DateTime->now();
    $args{'updated'} =  $now->ymd." ".$now->hms;
    my ($id) = $self->SUPER::create(%args);
    if ($self->id) { 
        $self->_add_revision(%args);
    }
    return($id);
}

=head2 _add_revision 

Adds a revision for this page. Called by  create and set_content

=over

=item content

=back

=cut

sub _add_revision {
    my $self = shift;
    my %args = (@_);

    my $rev = JiftyWiki::Model::Revision->new();
    $rev->create(
        page    => $self->id,
        content => $args{'content'}
    );

}

sub set_content {
    my $self = shift;
    my $content = shift;
    my ($val, $msg) = $self->SUPER::set_content($content);
    $self->_add_revision(content =>$content );
    return ($val,$msg);
}

sub _set {
    my $self = shift;
    my ($val,$msg) = $self->SUPER::_set(@_);
    my $now = DateTime->now();
    $self->SUPER::_set( column => 'updated', value =>   $now->ymd." ".$now->hms);
    return ($val,$msg);
}

1;
